==> better_with_time-2.0-sources.jar: com/bwt/tags/BwtBlockTags.java <==
package com.bwt.tags;

import com.bwt.utils.Id;
import net.minecraft.class_2248;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class BwtBlockTags {
    public static final class_6862<class_2248> BLOCK_DISPENSER_INHALE_NOOP = class_6862.method_40092(class_7924.field_41254, Id.of("block_dispenser_inhale_noop"));
    public static final class_6862<class_2248> BLOCK_DISPENSER_INHALE_VOID = class_6862.method_40092(class_7924.field_41254, Id.of("block_dispenser_inhale_void"));
    public static final class_6862<class_2248> DETECTABLE_SMALL_CROPS = class_6862.method_40092(class_7924.field_41254, Id.of("detectable_small_crops"));
    public static final class_6862<class_2248> SURVIVES_SAW_BLOCK = class_6862.method_40092(class_7924.field_41254, Id.of("survives_saw_block"));
    public static final class_6862<class_2248> SAW_BREAKS_NO_DROPS = class_6862.method_40092(class_7924.field_41254, Id.of("saw_breaks_no_drops"));
    public static final class_6862<class_2248> SAW_BREAKS_DROPS_LOOT = class_6862.method_40092(class_7924.field_41254, Id.of("saw_breaks_drops_loot"));
    public static final class_6862<class_2248> SIDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("siding_blocks"));
    public static final class_6862<class_2248> WOODEN_SIDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_siding_blocks"));
    public static final class_6862<class_2248> MOULDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("moulding_blocks"));
    public static final class_6862<class_2248> WOODEN_MOULDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_moulding_blocks"));
    public static final class_6862<class_2248> CORNER_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("corner_blocks"));
    public static final class_6862<class_2248> WOODEN_CORNER_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_corner_blocks"));
    public static final class_6862<class_2248> COLUMN_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("column_blocks"));
    public static final class_6862<class_2248> WOODEN_COLUMN_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_column_blocks"));
    public static final class_6862<class_2248> PEDESTAL_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("pedestal_blocks"));
    public static final class_6862<class_2248> WOODEN_PEDESTAL_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_pedestal_blocks"));
    public static final class_6862<class_2248> TABLE_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("table_blocks"));
    public static final class_6862<class_2248> WOODEN_TABLE_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_table_blocks"));
    public static final class_6862<class_2248> VASES = class_6862.method_40092(class_7924.field_41254, Id.of("vases"));
    public static final class_6862<class_2248> WOOL_SLABS = class_6862.method_40092(class_7924.field_41254, Id.of("wool_slabs"));
    public static final class_6862<class_2248> DOES_NOT_TRIGGER_BUDDY = class_6862.method_40092(class_7924.field_41254, Id.of("does_not_trigger_buddy"));
    public static final class_6862<class_2248> CROPS_CAN_PLANT_ON = class_6862.method_40092(class_7924.field_41254, Id.of("farmland"));
    public static final class_6862<class_2248> SOUL_SAND_PLANTS_CAN_PLANT_ON = class_6862.method_40092(class_7924.field_41254, Id.of("soul_sand_plants_can_plant_on"));
    public static final class_6862<class_2248> TRANSFERS_ROTATION_UPWARD_OVERRIDE = class_6862.method_40092(class_7924.field_41254, Id.of("transfers_rotation_upward_override"));
    public static final class_6862<class_2248> MATTOCK_MINEABLE = class_6862.method_40092(class_7924.field_41254, Id.of("mineable/mattock"));
    public static final class_6862<class_2248> BATTLEAXE_MINEABLE = class_6862.method_40092(class_7924.field_41254, Id.of("mineable/battle_axe"));
    public static final class_6862<class_2248> BLOOD_WOOD_LOGS = class_6862.method_40092(class_7924.field_41254, Id.of("blood_wood_logs"));
    public static final class_6862<class_2248> BLOOD_WOOD_PLANTABLE_ON = class_6862.method_40092(class_7924.field_41254, Id.of("blood_wood_plantable_on"));
    public static final class_6862<class_2248> CAN_CONVERT_TO_PODZOL = class_6862.method_40092(class_7924.field_41254, Id.of("can_convert_to_podzol"));
    public static final class_6862<class_2248> CAN_CONVERT_TO_PODZOL_SLAB = class_6862.method_40092(class_7924.field_41254, Id.of("can_convert_to_podzol_slab"));
    public static final class_6862<class_2248> NETHER_GROTH_CAN_EAT = class_6862.method_40092(class_7924.field_41254, Id.of("nether_groth_can_eat"));
}

==> better_with_time-2.0.2-sources.jar: com/bwt/tags/BwtBlockTags.java <==
package com.bwt.tags;

import com.bwt.utils.Id;
import net.minecraft.class_2248;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class BwtBlockTags {
    // When a BD attempts to inhale, the block will remain in the world and the BD won't gain any items
    public static final class_6862<class_2248> BLOCK_DISPENSER_INHALE_NOOP = class_6862.method_40092(class_7924.field_41254, Id.of("block_dispenser_inhale_noop"));
    // When a BD attempts to inhale, the block will be removed and the BD won't gain any items
    public static final class_6862<class_2248> BLOCK_DISPENSER_INHALE_VOID = class_6862.method_40092(class_7924.field_41254, Id.of("block_dispenser_inhale_void"));
    // Crops that, when fully grown one block in front of and below (diagonally down from) a Detector Block's face, will trigger the DB.
    public static final class_6862<class_2248> DETECTABLE_SMALL_CROPS = class_6862.method_40092(class_7924.field_41254, Id.of("detectable_small_crops"));
    // When placed in front of a powered saw, neither the saw nor the place block will break
    public static final class_6862<class_2248> SURVIVES_SAW_BLOCK = class_6862.method_40092(class_7924.field_41254, Id.of("survives_saw_block"));
    // When placed in front of a powered saw, the block will be removed with no drops
    public static final class_6862<class_2248> SAW_BREAKS_NO_DROPS = class_6862.method_40092(class_7924.field_41254, Id.of("saw_breaks_no_drops"));
    // When placed in front of a powered saw, the block will be removed and drop its default loot
    public static final class_6862<class_2248> SAW_BREAKS_DROPS_LOOT = class_6862.method_40092(class_7924.field_41254, Id.of("saw_breaks_drops_loot"));

    // Mini blocks
    // WOODEN_ blocks are mined with an axe and cut with a saw
    public static final class_6862<class_2248> SIDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("siding_blocks"));
    public static final class_6862<class_2248> WOODEN_SIDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_siding_blocks"));
    public static final class_6862<class_2248> MOULDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("moulding_blocks"));
    public static final class_6862<class_2248> WOODEN_MOULDING_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_moulding_blocks"));
    public static final class_6862<class_2248> CORNER_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("corner_blocks"));
    public static final class_6862<class_2248> WOODEN_CORNER_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_corner_blocks"));
    public static final class_6862<class_2248> COLUMN_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("column_blocks"));
    public static final class_6862<class_2248> WOODEN_COLUMN_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_column_blocks"));
    public static final class_6862<class_2248> PEDESTAL_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("pedestal_blocks"));
    public static final class_6862<class_2248> WOODEN_PEDESTAL_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_pedestal_blocks"));
    public static final class_6862<class_2248> TABLE_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("table_blocks"));
    public static final class_6862<class_2248> WOODEN_TABLE_BLOCKS = class_6862.method_40092(class_7924.field_41254, Id.of("wooden_table_blocks"));

    // All colors of vases
    public static final class_6862<class_2248> VASES = class_6862.method_40092(class_7924.field_41254, Id.of("vases"));
    // All colors of wool slabs
    public static final class_6862<class_2248> WOOL_SLABS = class_6862.method_40092(class_7924.field_41254, Id.of("wool_slabs"));

    // Blocks in this tag will not update the buddy block when placed, or when their state changes
    public static final class_6862<class_2248> DOES_NOT_TRIGGER_BUDDY = class_6862.method_40092(class_7924.field_41254, Id.of("does_not_trigger_buddy"));
    // Overriding the vanilla hard-coding of allowing crops to be planted on farmland, so we can add the planter pot
    public static final class_6862<class_2248> CROPS_CAN_PLANT_ON = class_6862.method_40092(class_7924.field_41254, Id.of("farmland"));
    // Overriding the vanilla hard-coding of allowing some plants to be placed on soul sand, so we can add the soul sand pot
    public static final class_6862<class_2248> SOUL_SAND_PLANTS_CAN_PLANT_ON = class_6862.method_40092(class_7924.field_41254, Id.of("soul_sand_plants_can_plant_on"));
    // Turntables only transfer their rotation up 2 blocks if the first block has a certain solid shape. This tag includes things like stairs and walls to include more shapes
    public static final class_6862<class_2248> TRANSFERS_ROTATION_UPWARD_OVERRIDE = class_6862.method_40092(class_7924.field_41254, Id.of("transfers_rotation_upward_override"));

    // Multitool mining, just includes the relevant sub-tool tags
    public static final class_6862<class_2248> MATTOCK_MINEABLE = class_6862.method_40092(class_7924.field_41254, Id.of("mineable/mattock"));
    public static final class_6862<class_2248> BATTLEAXE_MINEABLE = class_6862.method_40092(class_7924.field_41254, Id.of("mineable/battle_axe"));

    // Blood wood basic handling
    public static final class_6862<class_2248> BLOOD_WOOD_LOGS = class_6862.method_40092(class_7924.field_41254, Id.of("blood_wood_logs"));
    public static final class_6862<class_2248> BLOOD_WOOD_PLANTABLE_ON = class_6862.method_40092(class_7924.field_41254, Id.of("blood_wood_plantable_on"));

    // Overriding the vanilla behavior of converting dirt to podzol - we don't want to use the dirt tag for this
    public static final class_6862<class_2248> CAN_CONVERT_TO_PODZOL = class_6862.method_40092(class_7924.field_41254, Id.of("can_convert_to_podzol"));
    // Same thing but for our podzol slabs
    public static final class_6862<class_2248> CAN_CONVERT_TO_PODZOL_SLAB = class_6862.method_40092(class_7924.field_41254, Id.of("can_convert_to_podzol_slab"));
    // Nether Groth will consume some small plants (fungi, weeping vines)
    public static final class_6862<class_2248> NETHER_GROTH_CAN_EAT = class_6862.method_40092(class_7924.field_41254, Id.of("nether_groth_can_eat"));

    public static final class_6862<class_2248> HEATS_COOKING_STATIONS = class_6862.method_40092(class_7924.field_41254, Id.of("heats_cooking_stations"));
    public static final class_6862<class_2248> STOKES_COOKING_STATIONS = class_6862.method_40092(class_7924.field_41254, Id.of("stokes_cooking_stations"));
    public static final class_6862<class_2248> HEATS_COOKING_STATIONS_WHEN_LIT = class_6862.method_40092(class_7924.field_41254, Id.of("heats_cooking_stations_when_lit"));
    public static final class_6862<class_2248> STOKES_COOKING_STATIONS_WHEN_LIT = class_6862.method_40092(class_7924.field_41254, Id.of("stokes_cooking_stations_when_lit"));
}
